@@ -58,6 +58,8 @@ class ScreenObjectManager:
             caption = caption + f" - {ScreenObjectManager.BATCH_FILE}/{ScreenObjectManager.PRESET_FILE}"
         else:
             caption = caption + f" - {ScreenObjectManager.PRESET_FILE}"
+        if ScreenObjectManager.NEW_VERSION:
+            caption = f"[NEW VERSION AVAILABLE] {caption}"
         pygame.display.set_caption(caption)
         img_path = find_abs("Logo.png", allowed_areas=["package/assets/"])
         img = pygame.image.load(img_path)
@@ -91,8 +93,7 @@ class ScreenObjectManager:
         if obj.visual is not None and obj.visual.visible:
             self.registerVisual(obj.visual, key)
         for i, child in enumerate(obj.children):
-            new_key = key + str(child.__class__.__name__) + str(i)
-            self.registerObject(child, new_key)
+            self.registerObject(child, child.key)
 
     def applyToScreen(self):
         self.screen.fill(self.background_colour)
