@@ -33,12 +33,12 @@ def worldspace_to_screenspace(point):
 
     return (
         int(
-            point[0] * ScreenObjectManager.instance.screen_width / ScreenObjectManager.instance.map_width
-            + ScreenObjectManager.instance.screen_width / 2
+            point[0] * ScreenObjectManager.instance.SCREEN_WIDTH / ScreenObjectManager.instance.MAP_WIDTH
+            + ScreenObjectManager.instance.SCREEN_WIDTH / 2
         ),
         int(
-            -point[1] * ScreenObjectManager.instance.screen_height / ScreenObjectManager.instance.map_height
-            + ScreenObjectManager.instance.screen_height / 2
+            -point[1] * ScreenObjectManager.instance.SCREEN_HEIGHT / ScreenObjectManager.instance.MAP_HEIGHT
+            + ScreenObjectManager.instance.SCREEN_HEIGHT / 2
         ),
     )
 
@@ -49,14 +49,14 @@ def screenspace_to_worldspace(point):
     return np.array(
         [
             float(
-                (point[0] - ScreenObjectManager.instance.screen_width / 2)
-                / ScreenObjectManager.instance.screen_width
-                * ScreenObjectManager.instance.map_width
+                (point[0] - ScreenObjectManager.instance.SCREEN_WIDTH / 2)
+                / ScreenObjectManager.instance.SCREEN_WIDTH
+                * ScreenObjectManager.instance.MAP_WIDTH
             ),
             float(
-                -(point[1] - ScreenObjectManager.instance.screen_height / 2)
-                / ScreenObjectManager.instance.screen_height
-                * ScreenObjectManager.instance.map_height
+                -(point[1] - ScreenObjectManager.instance.SCREEN_HEIGHT / 2)
+                / ScreenObjectManager.instance.SCREEN_HEIGHT
+                * ScreenObjectManager.instance.MAP_HEIGHT
             ),
         ]
     )
